==> genome-spy-0.10.0.tgz: package/src/app/components/toolbar-wc.js <==
import { html, LitElement, nothing } from "lit";
import { icon } from "@fortawesome/fontawesome-svg-core";
import {
    faInfoCircle,
    faQuestionCircle,
    faExpandArrowsAlt,
    faArrowsAltV,
} from "@fortawesome/free-solid-svg-icons";
import { findGenomeScaleResolution } from "./searchField-wc";
import { asArray } from "../../utils/arrayUtils";
import bowtie from "../../img/bowtie.svg";
import { messageBox } from "../../utils/ui/modal";

export default class Toolbar extends LitElement {
    constructor() {
        super();

        /** @type {import("../genomeSpyApp").default} */
        this.app = undefined;

        /** Just to signal (and re-render) once GenomeSpy has been launched */
        this.appInitialized = false;
    }

    static get properties() {
        return {
            app: { type: Object },
            appInitialized: { type: Boolean },
        };
    }

    createRenderRoot() {
        return this;
    }

    _getToolButtons() {
        const sampleView = this.app.getSampleView();
        const provenance = this.app.provenance;

        /** @type {(import("lit").TemplateResult | string)[]} */
        const elements = [];

        // Check that there's an undoable state
        if (provenance.isEnabled()) {
            elements.push(
                html`
                    <genome-spy-provenance-buttons .provenance=${provenance} />
                `
            );
        }

        if (sampleView) {
            elements.push(html`
                <button
                    class="tool-btn"
                    title="Peek (E)"
                    @click=${() => sampleView._togglePeek()}
                >
                    ${icon(faArrowsAltV).node[0]}
                </button>
            `);
        }

        if (this.app.bookmarkDatabase) {
            elements.push(html`
                <genome-spy-bookmark-button></genome-spy-bookmark-button>
            `);
        }

        /**
         * The first entry in the description array is shown as a title in the toolbar
         */

        const description = this.app.config.description
            ? asArray(this.app.config.description)
            : [];

        if (description.length > 1) {
            elements.push(html`
                <button
                    class="tool-btn"
                    title="Show a description of the visualization"
                    @click=${() =>
                        messageBox(
                            html`${description
                                .slice(1)
                                .map((line) => html`<p>${line}</p>`)}`,
                            description[0]
                        )}
                >
                    ${icon(faInfoCircle).node[0]}
                </button>
            `);
        }

        if (description.length > 0) {
            elements.push(html`
                <span class="vis-title">${description[0]}</span>
            `);
        }

        elements.push(html`
            <span class="spacer"></span>

            <button
                class="tool-btn"
                title="Fullscreen"
                @click=${() => this.app.toggleFullScreen()}
            >
                ${icon(faExpandArrowsAlt).node[0]}
            </button>

            <button
                class="tool-btn"
                title="Help"
                @click=${() =>
                    window.open("https://genomespy.app/docs/", "_blank")}
            >
                ${icon(faQuestionCircle).node[0]}
            </button>
        `);

        return elements;
    }

    render() {
        const genomeSpy = this.app.genomeSpy;

        return html`
            <nav class="toolbar">
                <a href="https://genomespy.app" target="_blank" class="logo">
                    <img title="GenomeSpy" alt="GenomeSpy" src="${bowtie}" />
                </a>
                <div class="title">
                    <span>GenomeSpy</span>
                </div>

                ${this.appInitialized &&
                findGenomeScaleResolution(genomeSpy.viewRoot)
                    ? html`
                          <genome-spy-search-field
                              .genomeSpy=${genomeSpy}
                          ></genome-spy-search-field>
                      `
                    : nothing}
                ${this._getToolButtons()}
            </nav>
        `;
    }
}

customElements.define("genome-spy-toolbar", Toolbar);

==> genome-spy-0.11.0.tgz: package/src/app/components/toolbar-wc.js <==
import { html, LitElement, nothing } from "lit";
import { icon } from "@fortawesome/fontawesome-svg-core";
import {
    faInfoCircle,
    faQuestionCircle,
    faExpandArrowsAlt,
    faArrowsAltV,
} from "@fortawesome/free-solid-svg-icons";
import { findGenomeScaleResolution } from "./searchField-wc";
import { asArray } from "../../utils/arrayUtils";
import bowtie from "../../img/bowtie.svg";
import { messageBox } from "../utils/ui/modal";

export default class Toolbar extends LitElement {
    constructor() {
        super();

        /** @type {import("../genomeSpyApp").default} */
        this.app = undefined;

        /** Just to signal (and re-render) once GenomeSpy has been launched */
        this.appInitialized = false;
    }

    static get properties() {
        return {
            app: { type: Object },
            appInitialized: { type: Boolean },
        };
    }

    createRenderRoot() {
        return this;
    }

    _getToolButtons() {
        const sampleView = this.app.getSampleView();
        const provenance = this.app.provenance;

        /** @type {(import("lit").TemplateResult | string)[]} */
        const elements = [];

        // Check that there's an undoable state
        if (provenance.isEnabled()) {
            elements.push(
                html`
                    <genome-spy-provenance-buttons .provenance=${provenance} />
                `
            );
        }

        if (sampleView) {
            elements.push(html`
                <button
                    class="tool-btn"
                    title="Peek (E)"
                    @click=${() => sampleView._togglePeek()}
                >
                    ${icon(faArrowsAltV).node[0]}
                </button>
            `);
        }

        if (this.app.bookmarkDatabase) {
            elements.push(html`
                <genome-spy-bookmark-button></genome-spy-bookmark-button>
            `);
        }

        /**
         * The first entry in the description array is shown as a title in the toolbar
         */

        const description = this.app.config.description
            ? asArray(this.app.config.description)
            : [];

        if (description.length > 1) {
            elements.push(html`
                <button
                    class="tool-btn"
                    title="Show a description of the visualization"
                    @click=${() =>
                        messageBox(
                            html`${description
                                .slice(1)
                                .map((line) => html`<p>${line}</p>`)}`,
                            description[0]
                        )}
                >
                    ${icon(faInfoCircle).node[0]}
                </button>
            `);
        }

        if (description.length > 0) {
            elements.push(html`
                <span class="vis-title">${description[0]}</span>
            `);
        }

        elements.push(html`
            <span class="spacer"></span>

            <button
                class="tool-btn"
                title="Fullscreen"
                @click=${() => this.app.toggleFullScreen()}
            >
                ${icon(faExpandArrowsAlt).node[0]}
            </button>

            <button
                class="tool-btn"
                title="Help"
                @click=${() =>
                    window.open("https://genomespy.app/docs/", "_blank")}
            >
                ${icon(faQuestionCircle).node[0]}
            </button>
        `);

        return elements;
    }

    render() {
        const genomeSpy = this.app.genomeSpy;

        return html`
            <nav class="toolbar">
                <a href="https://genomespy.app" target="_blank" class="logo">
                    <img title="GenomeSpy" alt="GenomeSpy" src="${bowtie}" />
                </a>
                <div class="title">
                    <span>GenomeSpy</span>
                </div>

                ${this.appInitialized &&
                findGenomeScaleResolution(genomeSpy.viewRoot)
                    ? html`
                          <genome-spy-search-field
                              .genomeSpy=${genomeSpy}
                          ></genome-spy-search-field>
                      `
                    : nothing}
                ${this._getToolButtons()}
            </nav>
        `;
    }
}

customElements.define("genome-spy-toolbar", Toolbar);
